pub struct WaveformPacket {
pub descriptor_index: u8,
pub byte_offset: u64,
pub packet_size: u32,
pub return_point_loc: f32,
pub x_t: f32,
pub y_t: f32,
pub z_t: f32,
}Expand description
Waveform packet data per ASPRS LAS 1.4 R15 Tables 17-18. Present in point data record formats 9 and 10.
Fields
descriptor_index: u8Index into the Waveform Packet Descriptor lookup table (1-255).
byte_offset: u64Byte offset in the waveform data packets section (or external file).
packet_size: u32Size in bytes of the waveform data packet.
return_point_loc: f32Return point waveform location: parametric t value at which the associated return pulse was detected, measured in picoseconds.
x_t: f32X(t) parametric displacement in the direction of the laser pulse (metres per picosecond).
y_t: f32Y(t) parametric displacement in the direction of the laser pulse (metres per picosecond).
z_t: f32Z(t) parametric displacement in the direction of the laser pulse (metres per picosecond).